pub struct NoCollapseInfo {
pub rule_name: String,
pub span: (usize, usize),
pub rule_name_span: (usize, usize),
}Expand description
Owned representation of a @no_collapse directive.
Fields
rule_name: StringThe name of the rule to prevent span collapse for.
span: (usize, usize)Byte offset range of the entire directive.
rule_name_span: (usize, usize)Byte offset range of the rule name within the directive.